import { Notifier } from './notifier';
/**
 * Environment variable set when the plugin is run and intended to emit
 * a bundle.
 */
export declare const bundleEnv = "MIIX_PLZ_BUNDLE";
/**
 * The BundleEmitted packages everything up nicely and emits it to the
 * provided Notifier after the webpack compilation succeeds.
 */
export declare class BundleEmitter {
    private readonly notifier;
    private readonly isEnabled;
    /**
     * Target file to write the tarball into.
     */
    private readonly fileTarget;
    constructor(notifier: Notifier, isEnabled?: boolean);
    /**
     * Attaches the emitted to the webpack compiler.
     */
    apply(compiler: any): void;
    private startBundling(compiler);
    /**
     * Throws an PackageIntegrityError if there are any obvious problems with
     * the bundler output.
     */
    private verifyIntegrity(output);
    /**
     * Tries to render the readme in the project, returning the HTML
     * if it's able to do so.
     */
    private renderReadme(projectPath);
    /**
     * Compresses the output dir into the target tarball.
     */
    private createTarball(projectPath, output);
}
