"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
/**
 * Takes a function that wants a callback, and resolves when that callback
 * is resolved upon or errored.
 */
function promiseCallback(fn) {
    return __awaiter(this, void 0, void 0, function* () {
        return new Promise((resolve, reject) => {
            fn((err, result) => {
                if (err) {
                    reject(err);
                }
                else {
                    resolve(result);
                }
            });
        });
    });
}
exports.promiseCallback = promiseCallback;
/**
 * Promisified fs.readFile
 */
function readFile(file) {
    return __awaiter(this, void 0, void 0, function* () {
        return promiseCallback(callback => {
            fs.readFile(file, 'utf8', callback);
        });
    });
}
exports.readFile = readFile;
/**
 * Promisified fs.exists
 */
function exists(file) {
    return __awaiter(this, void 0, void 0, function* () {
        return new Promise(resolve => {
            fs.exists(file, resolve);
        });
    });
}
exports.exists = exists;
/**
 * Promisified fs.readDir
 */
function readDir(dir) {
    return __awaiter(this, void 0, void 0, function* () {
        return promiseCallback(callback => {
            fs.readdir(dir, callback);
        });
    });
}
exports.readDir = readDir;
