"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const parse5 = require("parse5");
const errors_1 = require("./errors");
const fs_1 = require("./fs");
/**
 * The HTMLInjector is a helper that is able to inject HTML fragments into
 * an HTML document.
 */
class HTMLInjector {
    constructor(filepath) {
        this.filepath = filepath;
    }
    render(compiler) {
        return __awaiter(this, void 0, void 0, function* () {
            const parsed = yield this.getDocument();
            const head = this.findNode(parsed, ['html', 'head']);
            if (!head) {
                throw new errors_1.MixerPluginError('Your homepage is missing a <head> section!');
            }
            this.prepend(head, ...(yield this.injectHead(compiler)));
            return parse5.serialize(parsed);
        });
    }
    /**
     * injectHead returns a list of HTML fragments to insert into the page <head>.
     */
    injectHead(_compiler) {
        return __awaiter(this, void 0, void 0, function* () {
            return [];
        });
    }
    getDocument() {
        return __awaiter(this, void 0, void 0, function* () {
            const og = yield fs_1.readFile(this.filepath);
            try {
                return parse5.parse(og);
            }
            catch (e) {
                throw new Error(`Could not parse HTML from your homeage: ${e.stack}`);
            }
        });
    }
    prepend(parent, ...elements) {
        if (!parent.childNodes) {
            throw new Error('Attempted to append to non-parent node');
        }
        const casted = parent;
        elements.forEach(element => casted.childNodes.unshift(this.stringToNode(element)));
    }
    stringToNode(src) {
        const fragment = parse5.parseFragment(src);
        return fragment.childNodes[0];
    }
    findNode(parent, nodePath) {
        for (let i = 0; i < nodePath.length; i++) {
            if (!parent.childNodes) {
                return undefined;
            }
            const child = parent.childNodes.find(n => n.tagName === nodePath[i]);
            if (!child) {
                return undefined;
            }
            parent = child;
        }
        return parent;
    }
}
exports.HTMLInjector = HTMLInjector;
/**
 * HomepageRenderer is responsible for modifying and injecting Mixer stdlib
 * scripts into the developer's index.html.
 */
class HomepageRenderer extends HTMLInjector {
    constructor(filepath, packaged, locales) {
        super(filepath);
        this.packaged = packaged;
        this.locales = locales;
    }
    injectHead() {
        return __awaiter(this, void 0, void 0, function* () {
            return [
                `<script>window.mixerPackageConfig=${JSON.stringify(this.packaged)};` +
                    `window.mixerLocales=${JSON.stringify(this.locales)}</script>`,
            ];
        });
    }
}
exports.HomepageRenderer = HomepageRenderer;
