"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const webpack_tools_1 = require("./webpack-tools");
const glob = require("glob");
const json5 = require("json5");
const path = require("path");
const errors_1 = require("./errors");
const fs_1 = require("./fs");
/**
 * The LocalePackager takes a glob on the filesystem and returns a map of
 * locale names to their parsed data.
 */
class LocalePackager {
    constructor(compilation) {
        this.compilation = compilation;
    }
    /**
     * compile loads locales matching the glob pattern to a map of locales
     * (from the file basenames) to their contents.
     */
    compile(pattern) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!pattern) {
                return {};
            }
            const { context } = this.compilation.compiler;
            const files = glob.sync(pattern, { cwd: context });
            const output = {};
            yield Promise.all(files.map((file) => __awaiter(this, void 0, void 0, function* () {
                if (!path.isAbsolute(file)) {
                    file = path.resolve(context, file);
                }
                else {
                    file = path.resolve(file);
                }
                const contents = yield fs_1.readFile(file);
                let parsed;
                try {
                    parsed = json5.parse(contents);
                }
                catch (err) {
                    throw new errors_1.MixerPluginError(`Could not parse ${file}: ${err.message || err}`);
                }
                webpack_tools_1.addFilesToCompilation(this.compilation, file);
                output[path.basename(file, path.extname(file))] = parsed;
            })));
            this.addToCompilation(output);
            return output;
        });
    }
    /**
     * Adds the compile()'d locale data to the webpack compilation,
     * in the locales folder.
     */
    addToCompilation(data) {
        Object.keys(data).forEach(key => {
            this.compilation.assets[`locales/${key}.json`] = webpack_tools_1.contentsToAsset(JSON.stringify(data[key]));
        });
    }
}
exports.LocalePackager = LocalePackager;
