"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const fs_1 = require("./fs");
/**
 * Finds the nearest package.json relative to the given directory, returning
 * undefined if it's not found.
 */
function findPackageJson(dir) {
    return __awaiter(this, void 0, void 0, function* () {
        const parts = path.resolve(dir).split(path.sep);
        while (parts.length > 0) {
            const packagePath = [...parts, 'package.json'].join(path.sep);
            if (yield fs_1.exists(packagePath)) {
                return packagePath;
            }
            parts.pop();
        }
        return undefined;
    });
}
exports.findPackageJson = findPackageJson;
/**
 * Loads data from the project's package.json, throwing an error if it can't
 * be loaded.
 */
function mustLoadPackageJson(dir) {
    return __awaiter(this, void 0, void 0, function* () {
        const jsonPath = yield findPackageJson(dir);
        if (jsonPath) {
            return JSON.parse(yield fs_1.readFile(jsonPath)); // tslint:disable-line
        }
        throw new Error('Could not find a package.json in your current folder, ' +
            'make sure to `cd` into your project directory!');
    });
}
exports.mustLoadPackageJson = mustLoadPackageJson;
/**
 * Returns the base path of a project nested in the given directory (the
 * folder containing the package.json).
 */
function getProjectPath(dir) {
    return __awaiter(this, void 0, void 0, function* () {
        const json = yield findPackageJson(dir);
        return json ? path.dirname(json) : undefined;
    });
}
exports.getProjectPath = getProjectPath;
/**
 * Finds the readme for the project in the given directory. Uses a similar
 * process to npm.
 */
function findReadme(dir) {
    return __awaiter(this, void 0, void 0, function* () {
        const fname = (yield fs_1.readDir(dir)).find(f => /^readme\.?/i.test(f));
        if (fname) {
            return path.join(dir, fname);
        }
        try {
            const packageJson = yield mustLoadPackageJson(dir);
            return packageJson && path.normalize(path.resolve(dir, packageJson.readmeFile));
        }
        catch (e) {
            return undefined;
        }
    });
}
exports.findReadme = findReadme;
/**
 * Copies a file from one place to another.
 */
function copy(source, destination) {
    return __awaiter(this, void 0, void 0, function* () {
        return new Promise((resolve, reject) => {
            fs
                .createReadStream(source)
                .pipe(fs.createWriteStream(destination))
                .on('error', reject)
                .on('close', resolve);
        });
    });
}
exports.copy = copy;
