"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const fs_1 = require("./fs");
/**
 * Adds a file by path as a dependency of the compilation, if it doesn't
 * already exist.
 */
function addFilesToCompilation(compilation, files) {
    if (!(files instanceof Array)) {
        files = [files];
    }
    files.forEach(file => {
        if (!path.isAbsolute(file)) {
            throw new Error(`Expected path to be absolute: ${file}`);
        }
        if (compilation.fileDependencies instanceof Array) {
            // webpack < 4
            if (!compilation.fileDependencies.includes(file)) {
                compilation.fileDependencies.push(file);
            }
        }
        else {
            // webpack 4, SortedSet
            compilation.fileDependencies.add(file);
        }
    });
}
exports.addFilesToCompilation = addFilesToCompilation;
/**
 * Converts the data to a webpack asset.
 */
function contentsToAsset(contents) {
    return {
        source: () => contents,
        size: () => contents.length,
    };
}
exports.contentsToAsset = contentsToAsset;
/**
 * Converts the given file to a webpack asset.
 */
function fileToAsset(...segments) {
    return __awaiter(this, void 0, void 0, function* () {
        return fs_1.readFile(path.resolve(...segments)).then(contentsToAsset);
    });
}
exports.fileToAsset = fileToAsset;
