"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const path_1 = require("path");
const locale_packager_1 = require("../src/locale-packager");
describe('Locale packager', () => {
    function checkOutput(cmp, results) {
        chai_1.expect(cmp.fileDependencies.sort()).to.deep.equal([
            path_1.join(__dirname, 'fixtures', 'locales', 'en.json'),
            path_1.join(__dirname, 'fixtures', 'locales', 'es.json'),
        ]);
        chai_1.expect(results).to.deep.equal({
            en: {
                hello: 'world',
            },
            es: {
                hola: 'mundo',
            },
        });
    }
    it('loads locales correctly with an absolute glob', () => __awaiter(this, void 0, void 0, function* () {
        const cmp = { fileDependencies: [], assets: {}, compiler: { context: __dirname } };
        const results = yield new locale_packager_1.LocalePackager(cmp).compile(`${__dirname}/fixtures/locales/*.json`);
        checkOutput(cmp, results);
    }));
    it('loads locales correctly with a relative glob', () => __awaiter(this, void 0, void 0, function* () {
        const cmp = { fileDependencies: [], assets: {}, compiler: { context: __dirname } };
        const results = yield new locale_packager_1.LocalePackager(cmp).compile(`fixtures/locales/*.json`);
        checkOutput(cmp, results);
    }));
    it('loads locales correctly with a weird glob', () => __awaiter(this, void 0, void 0, function* () {
        const cmp = { fileDependencies: [], assets: {}, compiler: { context: `${__dirname}/wut` } };
        const results = yield new locale_packager_1.LocalePackager(cmp).compile(`../fixtures/locales/*.json`);
        checkOutput(cmp, results);
    }));
});
